==> aloe-1.3.tar.gz: aloe-1.3/modules/wimax_deinterleaver/interfaces/inputs.h <==
/*
 * Define here the outputs for the module
 */

#ifndef _INPUTS_H
#define	_INPUTS_H

/** Type declaration */
#include "CInterleaver.h"

typedef float symbolIN;	/*Defined according the data needs*/

#define INPUT_MAX_DATA	4096	/*Max buffer size for data symbols*/
#define INPUT_MAX_CONTROL  1

/* buffer for data */
symbolIN input_data[INPUT_MAX_DATA];		/*DATA BUFFER*/	
CInter control_inter;				/*CONTROL BUFFER*/


/* defined interfaces functions*/
int get_datain_length();
int process_inputdata();
int get_controlin_length();
int process_inputcontrol();

/** configure input interfaces */
/*Better define first control flow: Flows processed according definition position*/
struct utils_itf input_itfs[] = {
               		{"control_flow_in",          	/**<< Name of the interface */
                 	sizeof(CInter), 		/**<< Size of the sample (in bytes) */
                 	INPUT_MAX_CONTROL,   		/**<< Pointer where to store data */
                 	&control_inter,       		/**<< Buffer for data */
                 	get_controlin_length, 		/**Returns number of samples to read from flow
                                              		Set to NULL to read all */
                 	process_inputcontrol,   	/**<< Function to process data */
                	},	
			{
			"data_flow_in",                     	/**<< Name of the interface */
        		sizeof(symbolIN),               /**<< Size of the sample, in bytes */
			INPUT_MAX_DATA,             	/**<< Max buffer length in samples */
			input_data,                   	/**<< Pointer where to store data */
        		get_datain_length,	    	/**<< Returns number of samples to read from flow
                                              		Set to NULL to read all */
			process_inputdata,		/**<< Function to process the data */
			},
                    	{NULL, 0, 0, 0, 0, 0}};

/** =============== End ================  */

#endif	/* _INPUTS_H */

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/wimax_deinterleaver/interfaces/inputs.h <==
/*
 * Define here the outputs for the module
 */

#ifndef _INPUTS_H
#define	_INPUTS_H

/** Type declaration */
#include "itf_types.h"

typedef float symbolIN;	/*Defined according the data needs*/

#define INPUT_MAX_DATA	4096	/*Max buffer size for data symbols*/
#define INPUT_MAX_CONTROL  1

/* buffer for data */
symbolIN input_data[INPUT_MAX_DATA];		/*DATA BUFFER*/	
CDeInter control_inter;				/*CONTROL BUFFER*/


/* defined interfaces functions*/
int get_datain_length();
int process_inputdata();
int get_controlin_length();
int process_inputcontrol();

/** configure input interfaces */
/*Better define first control flow: Flows processed according definition position*/
struct utils_itf input_itfs[] = {
               		{"control_flow_in",          	/**<< Name of the interface */
                 	sizeof(CDeInter), 		/**<< Size of the sample (in bytes) */
                 	INPUT_MAX_CONTROL,   		/**<< Pointer where to store data */
                 	&control_inter,       		/**<< Buffer for data */
                 	get_controlin_length, 		/**Returns number of samples to read from flow
                                              		Set to NULL to read all */
                 	process_inputcontrol,   	/**<< Function to process data */
                	},	
			{
			"data_flow_in",                     	/**<< Name of the interface */
        		sizeof(symbolIN),               /**<< Size of the sample, in bytes */
			INPUT_MAX_DATA,             	/**<< Max buffer length in samples */
			input_data,                   	/**<< Pointer where to store data */
        		get_datain_length,	    	/**<< Returns number of samples to read from flow
                                              		Set to NULL to read all */
			process_inputdata,		/**<< Function to process the data */
			},
                    	{NULL, 0, 0, 0, 0, 0}};

/** =============== End ================  */

#endif	/* _INPUTS_H */
